@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_SESSIONLOGGER_P_H
-#define KIMAP_SESSIONLOGGER_P_H
+#pragma once
 
 #include <QFile>
 
@@ -32,4 +31,3 @@ private:
 
 }
 
-#endif
